@@ -560,8 +560,19 @@ class google_routesearch:
                         info = "%s\n%s" % ( self.osmMapa.distance_to_string(dis_to_key), m[2] )
                         self.osmMapa.draw_cloud( cr, 50,5, info, 20, False)
 
-                        dist = "track: %s / %s " % (self.osmMapa.distance_to_string(dis_done), self.osmMapa.distance_to_string(dis_total) )
-                        self.osmMapa.draw_cloud( cr, 150,-40, dist, 15, False)
+
+                        tTotal = t-self.rout_t_start
+                        speed = (dis_done/tTotal)*3600
+                        self.rout_avg_speed = self.osmMapa.distance_to_string( speed )
+                        t_todo = ((dis_total-dis_done)/speed)*60
+                        dist = "total:%s done %s in %i min. avr: %s/h at place in: %i min." % (
+                                                               self.osmMapa.distance_to_string(dis_total),
+                                                               self.osmMapa.distance_to_string(dis_done),
+                                                               (tTotal/60),
+                                                               self.rout_avg_speed,
+                                                               t_todo
+                                                               )
+                        self.osmMapa.draw_cloud( cr, 150,-31, dist, 15, False)
 
                         if m[4]<> None:
                             ico = cairo.ImageSurface.create_from_png( m[4] )
@@ -641,6 +652,10 @@ class google_routesearch:
         self.markers_lang = []
         self.my_point = -1
 
+        self.rout_avg_speed = 0.0
+        self.rout_t_start = int( time.strftime("%Y%m%d%H%M%S", time.localtime() ) )
+        self.rout_t_done = 0
+
     def on_clear(self, w, dialog):
         self.clean_layer()
         dialog.destroy()
