@@ -63,6 +63,8 @@ gtk.gdk.threads_init()
 name = "yosmapa"
 version = "0.19"
 """
+0.19-3
+    plugin[google_routesearch] trip predictions
 0.19-2
     plugin[google_routesearch] full multi lang support
 0.19-1
